@@ -123,7 +123,7 @@ async def run_client(inst, cmd, sshAgent=None, scpSrcFilePath=None, dlDirPath='.
         #sshAgent = os.getenv( 'SSH_AUTH_SOCK' )
         #async with asyncssh.connect(host, port=port, username=user, password=password, known_hosts=None) as conn:
         async with asyncssh.connect(host, port=port, username=user,
-            keepalive_interval=30, keepalive_count_max=6, login_timeout=120,
+            keepalive_interval=30, keepalive_count_max=12, login_timeout=120,
             known_hosts=known_hosts, agent_path=sshAgent ) as conn:
             serverHostKey = conn.get_server_host_key()
             #logger.info( 'got serverHostKey (%s) %s', type(serverHostKey), serverHostKey )
@@ -368,7 +368,12 @@ def tellInstances( instancesSpec, command=None, resultsLogFilePath=None,
         eventLoop.set_debug(True)
     if stopOnSigterm:
         origHandler = signal.getsignal( signal.SIGTERM )
-        eventLoop.add_signal_handler(signal.SIGTERM, sigtermHandler)
+        try:
+            eventLoop.add_signal_handler(signal.SIGTERM, sigtermHandler)
+        except NotImplementedError:
+            logger.info( 'could not add_signal_handler (normal on Windows, not normal on Linux')
+        except Exception as exc:
+            logger.warning( 'add_signal_handler gave exception (%s) %s', type(exc), exc )
     try:
         statuses = eventLoop.run_until_complete(run_multiple_clients(
             startedInstances, program, scpSrcFilePath=upload,
